@@ -10,7 +10,7 @@ def test_frontal_face_detector():
     pcs = dlib_detector(takeo_copy)
     assert len(pcs) == 1
     assert takeo_copy.n_channels == 3
-    assert takeo_copy.landmarks['dlib_0'].n_points == 4
+    assert takeo_copy.landmarks["dlib_0"].n_points == 4
 
 
 def test_frontal_face_detector_rgb():
@@ -20,7 +20,7 @@ def test_frontal_face_detector_rgb():
     pcs = dlib_detector(takeo_copy, greyscale=False)
     assert len(pcs) == 1
     assert takeo_copy.n_channels == 3
-    assert takeo_copy.landmarks['dlib_0'].n_points == 4
+    assert takeo_copy.landmarks["dlib_0"].n_points == 4
 
 
 def test_frontal_face_detector_upscales():
@@ -29,4 +29,4 @@ def test_frontal_face_detector_upscales():
     pcs = dlib_detector(takeo_copy, n_upscales=1)
     assert len(pcs) == 1
     assert takeo_copy.n_channels == 3
-    assert takeo_copy.landmarks['dlib_0'].n_points == 4
+    assert takeo_copy.landmarks["dlib_0"].n_points == 4
