@@ -1,5 +1,7 @@
-from menpodetect.opencv import (load_opencv_frontal_face_detector,
-                                load_opencv_eye_detector)
+from menpodetect.opencv import (
+    load_opencv_frontal_face_detector,
+    load_opencv_eye_detector,
+)
 import menpo.io as mio
 
 takeo = mio.import_builtin_asset.takeo_ppm()
@@ -11,7 +13,7 @@ def test_frontal_face_detector():
     pcs = opencv_detector(takeo_copy)
     assert len(pcs) == 1
     assert takeo_copy.n_channels == 3
-    assert takeo_copy.landmarks['opencv_0'].n_points == 4
+    assert takeo_copy.landmarks["opencv_0"].n_points == 4
 
 
 def test_frontal_face_detector_min_neighbors():
@@ -30,5 +32,5 @@ def test_eye_detector():
     assert takeo_copy.n_channels == 3
     # This is because appyveyor and travis (automated testing) return
     # a different number of detections
-    first_l = list(takeo_copy.landmarks.items_matching('opencv_*'))[0][1]
+    first_l = list(takeo_copy.landmarks.items_matching("opencv_*"))[0][1]
     assert first_l.n_points == 4
